# TACC CMS - Stylesheets - Built

DO __NOT__ AUTHOR STYLESHEETS HERE!

- Files here are the output of the `npm run build` step.
- Files here will be picked up by the django `collectstatic` step and served.

See [project `README.md` at "Building Static Resources"](/README.md#Building%20Static%20Resources).
